==> qtjambi-location-debuginfo-macos-5.15.17.jar: sources/QtJambiLocation/QPlaceContentReply_shell.h <==
#ifndef QPLACECONTENTREPLY_SHELL_H
#define QPLACECONTENTREPLY_SHELL_H

#include <QtCore/QtGlobal>
#include <QtCore/qcompilerdetection.h>

QT_WARNING_DISABLE_DEPRECATED

#include <QtLocation/qplacecontentreply.h>
#include <QtJambi/QtJambiAPI>
#include <QtCore/QList>
#include <QtCore/QMap>
#include <QtCore/QVariant>
#include <QtCore/qbytearray.h>
#include <QtCore/qcoreevent.h>
#include <QtCore/qmetaobject.h>
#include <QtCore/qnamespace.h>
#include <QtCore/qobject.h>
#include <QtCore/qregexp.h>
#include <qtcore-config.h>
#if QT_CONFIG(regularexpression)
#include <QtCore/qregularexpression.h>
#endif //QT_CONFIG(regularexpression)
#include <QtCore/qthread.h>
#include <QtCore/qtimer.h>
#include <QtLocation/qplacecontent.h>
#include <QtLocation/qplacecontentrequest.h>
#include <QtLocation/qplacereply.h>
#include <QtJambi/RegistryAPI>


class QPlaceContentReply_shell : public QPlaceContentReply, public QtJambiShellInterface
{
public:
    QPlaceContentReply_shell(QObject* parent0 = nullptr);
    ~QPlaceContentReply_shell() override;

    void abort() override;
    void childEvent(QChildEvent* event0) override;
    void connectNotify(const QMetaMethod& signal0) override;
    void customEvent(QEvent* event0) override;
    void disconnectNotify(const QMetaMethod& signal0) override;
    bool event(QEvent* event0) override;
    bool eventFilter(QObject* watched0, QEvent* event1) override;
    void timerEvent(QTimerEvent* event0) override;
    QPlaceReply::Type type() const override;
    static void operator delete(void * ptr) noexcept;
    const QMetaObject *metaObject() const override final;
    void *qt_metacast(const char *) override final;
    int qt_metacall(QMetaObject::Call, int, void **) override final;
private:
    QtJambiShell* __shell() const override final;
    jmethodID __shell_javaMethod(int pos) const;
};

struct QPlaceContentReply_access : public QPlaceContentReply
{
    void __qt_setContent_cref_QMap(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, jobject content0);
    void __qt_setNextPageRequest_cref_QPlaceContentRequest(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, QtJambiNativeID next0);
    void __qt_setPreviousPageRequest_cref_QPlaceContentRequest(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, QtJambiNativeID previous0);
    void __qt_setRequest_cref_QPlaceContentRequest(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, QtJambiNativeID request0);
    void __qt_setTotalCount_int(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, jint total0);
    jint __qt_type(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId) const;
};

#endif // QPLACECONTENTREPLY_SHELL_H

==> qtjambi-location-debuginfo-macos-5.15.20.jar: sources/QtJambiLocation/QPlaceContentReply_shell.h <==
#ifndef QPLACECONTENTREPLY_SHELL_H
#define QPLACECONTENTREPLY_SHELL_H

#include <QtCore/QtGlobal>
#include <QtCore/qcompilerdetection.h>

QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wdeprecated-declarations")

#include <QtLocation/qplacecontentreply.h>
#include <QtJambi/QtJambiAPI>
#include <QtCore/QList>
#include <QtCore/QMap>
#include <QtCore/QVariant>
#include <QtCore/qbytearray.h>
#include <QtCore/qcoreevent.h>
#include <QtCore/qmetaobject.h>
#include <QtCore/qnamespace.h>
#include <QtCore/qobject.h>
#include <QtCore/qregexp.h>
#include <qtcore-config.h>
#if QT_CONFIG(regularexpression)
#include <QtCore/qregularexpression.h>
#endif //QT_CONFIG(regularexpression)
#include <QtCore/qthread.h>
#include <QtCore/qtimer.h>
#include <QtLocation/qplacecontent.h>
#include <QtLocation/qplacecontentrequest.h>
#include <QtLocation/qplacereply.h>
#include <QtJambi/RegistryAPI>


class QPlaceContentReply_shell : public QPlaceContentReply, public QtJambiShellInterface
{
public:
    QPlaceContentReply_shell(QObject* parent0 = nullptr);
    ~QPlaceContentReply_shell() override;

    void abort() override;
    void childEvent(QChildEvent* event0) override;
    void connectNotify(const QMetaMethod& signal0) override;
    void customEvent(QEvent* event0) override;
    void disconnectNotify(const QMetaMethod& signal0) override;
    bool event(QEvent* event0) override;
    bool eventFilter(QObject* watched0, QEvent* event1) override;
    void timerEvent(QTimerEvent* event0) override;
    QPlaceReply::Type type() const override;
    static void operator delete(void * ptr) noexcept;
    const QMetaObject *metaObject() const override final;
    void *qt_metacast(const char *) override final;
    int qt_metacall(QMetaObject::Call, int, void **) override final;
private:
    QtJambiShell* __shell() const override final;
    jmethodID __shell_javaMethod(int pos) const;
};

struct QPlaceContentReply_access : public QPlaceContentReply
{
    void __qt_setContent_cref_QMap(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, jobject content0);
    void __qt_setNextPageRequest_cref_QPlaceContentRequest(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, QtJambiNativeID next0);
    void __qt_setPreviousPageRequest_cref_QPlaceContentRequest(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, QtJambiNativeID previous0);
    void __qt_setRequest_cref_QPlaceContentRequest(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, QtJambiNativeID request0);
    void __qt_setTotalCount_int(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, jint total0);
    jint __qt_type_constfct(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId) const;
};

#endif // QPLACECONTENTREPLY_SHELL_H
